import { Button, Flex, Input, Popconfirm, Space, Table } from "antd";
import Column from "antd/es/table/Column";
import { useEffect, useState } from "react";
import axiosInstance from "../../api/axios";
import DeviceDetailModal from "../deviceAdmin/DeviceDetailModal";
import UserDetailModal from "./UserDetailModal";

export default function UserManage() {
  const [users, setUsers] = useState([]);
  const [teams, setTeams] = useState([]);
  const [modalMode, setModalMode] = useState();
  const [selectedUser, setSelectedUser] = useState();
  const [modalOpen, setModalOpen] = useState(false);
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    total: 0,
  });

  const fetchData = async (pagination, name) => {
    const data = await axiosInstance.get("/user", {
      params: {
        page: pagination.current,
        size: pagination.pageSize,
        name: name,
      },
    });
    setUsers(data.records);
    setPagination({
      ...pagination,
      total: data.total,
    });
  };

  const fetchTeams = async () => {
    const data = await axiosInstance.get("/teams");
    setTeams(data);
  };

  useEffect(() => {
    // fetchTeams();
    fetchData({
      current: 1,
      pageSize: 10,
    });
  }, []);

  const handlePageChange = async (pagination) => {
    await fetchData(pagination);
  };

  const handleSearch = async (value) => {
    await fetchData(
      {
        ...pagination,
        current: 1,
      },
      value
    );
  };

  const handleDelete = async (record) => {
    await axiosInstance.delete(`/user/${record.userId}`);
    fetchData({
      current: 1,
      pageSize: 10,
    });
  };
  // 姓名、账号、联系电话、所属团队、操作
  return (
    <>
      <Flex justify="space-between">
        <Input.Search
          placeholder="请输入用户姓名"
          onSearch={handleSearch}
          style={{ width: "200px" }}
          className="m-4"
        />
        <Button
          className="m-4"
          type="primary"
          onClick={() => {
            setModalMode("create");
            setSelectedUser(null);
            setModalOpen(true);
          }}
        >
          添加用户
        </Button>
      </Flex>
      <Table
        rowKey="userId"
        dataSource={users}
        pagination={pagination}
        onChange={handlePageChange}
      >
        <Column title="姓名" key="name" dataIndex="name" />
        <Column title="账号" key="username" dataIndex="username" />
        <Column title="联系电话" key="phone" dataIndex="phone" />
        <Column title="所属团队" key="team" dataIndex="team" />
        <Column
          title="操作"
          render={(_, record) => {
            return (
              <Space>
                <Button
                  size="small"
                  onClick={() => {
                    setSelectedUser(record);
                    setModalOpen(true);
                    setModalMode("edit");
                  }}
                >
                  编辑
                </Button>
                <Popconfirm
                  title="删除用户"
                  description="确认要删除该用户吗？"
                  onConfirm={() => handleDelete(record)}
                >
                  <Button danger size="small">
                    删除
                  </Button>
                </Popconfirm>
              </Space>
            );
          }}
        />
      </Table>
      <UserDetailModal
        visiable={modalOpen}
        mode={modalMode}
        user={selectedUser}
        onclose={() => {
          setModalOpen(false);
          setSelectedUser(null);
        }}
        onSuccess={async () => {
          await fetchData({
            ...pagination,
            current: 1,
          });
        }}
      />
    </>
  );
}
